@@ -11,7 +11,6 @@
 #include <QDialog>
 #include <QLabel>
 
-#include <KDirLister>
 #include <KDirWatch>
 
 QT_FORWARD_DECLARE_CLASS(QDir)
@@ -22,7 +21,6 @@ class KQuery;
 class KFileItem;
 class KfindTabWidget;
 class KFindTreeView;
-class QLabel;
 class QPushButton;
 class QStatusBar;
 
@@ -72,7 +70,6 @@ private:
 
     bool isResultReported;
     KQuery *query;
-    KDirLister *dirlister;
     KDirWatch *dirwatch;
 };
 
